@@ -25,7 +25,7 @@ macro_rules! define {
     // One-transition defined machines
     ($input: literal -$transition: literal -> $output: literal $(,)?) => {
         {
-            let mut _var = $crate::model::machine::Machine::new();
+            let mut _var = $crate::core::machine::Machine::new();
             define!(_var => $input - $transition -> $output)
         }
     };
@@ -33,7 +33,7 @@ macro_rules! define {
     // Multiple-transitions defined machines
     ($input: literal -$transition: literal -> $output: literal $(, $input2: literal -$transition2: literal -> $output2: literal)* $(,)?) => {{
         {
-            let mut _var = $crate::model::machine::Machine::new();
+            let mut _var = $crate::core::machine::Machine::new();
             define!(
                  _var => $input -$transition-> $output $(, $input2 -$transition2 -> $output2)+
             )
@@ -43,7 +43,7 @@ macro_rules! define {
     // Parsing one transition with remaining transitions
     ($machine: ident => $(,)? $input: literal -$transition: literal -> $output: literal $(, $input2: literal -$transition2: literal -> $output2: literal)+) => {{
         {
-            $machine.add_transition($crate::model::transition::Transition::new($input.to_string(), $transition.to_string(), $output.to_string()));
+            $machine.add_transition($crate::core::transition::Transition::new($input.to_string(), $transition.to_string(), $output.to_string()));
             define!($machine => $(, $input2 -$transition2 -> $output2)?)
         }
     }};
@@ -51,7 +51,7 @@ macro_rules! define {
     // Parsing one transition with no remaining transition
     ($machine: ident => $(,)? $input: literal -$transition: literal -> $output: literal) => {
         {
-            $machine.add_transition($crate::model::transition::Transition::new($input.to_string(), $transition.to_string(), $output.to_string()));
+            $machine.add_transition($crate::core::transition::Transition::new($input.to_string(), $transition.to_string(), $output.to_string()));
             $machine
         }
     };
